==> alliance-5.0-20020701.tar.gz: alliance-5.0/xsch/src/XMX_icon.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XSCH                            |
|                                                             |
| File    :                   Icon.c                          |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                   01.06.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include <stdio.h>
# include <Xm/Xm.h>
# include <Xm/PushB.h>
# include <Xm/Form.h>
# include <Xm/Frame.h>
 
# include "mut.h"
# include "aut.h"
# include "mlo.h"
# include "XSB.h"
# include "XTB.h"
# include "XMX.h"

# include "XMX_icon.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/

  static char IconBits[] = {

   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x07,
   0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x7f,
   0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00,
   0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0xc0, 0x03,
   0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x04, 0x00, 0x00, 0x00, 0x40, 0x00,
   0x40, 0xfc, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x84, 0x00, 0x00, 0x00,
   0x40, 0x00, 0xc0, 0x83, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x80, 0x00,
   0x00, 0x00, 0x40, 0x00, 0x40, 0x80, 0xf8, 0xff, 0x00, 0x40, 0x00, 0x40,
   0x80, 0xc8, 0x80, 0x00, 0x7f, 0x00, 0x40, 0x80, 0x08, 0x83, 0x00, 0x40,
   0x00, 0x20, 0x80, 0x0f, 0x8c, 0x00, 0x40, 0x00, 0x18, 0x00, 0x08, 0xb0,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x08, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x03,
   0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,
   0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xc0, 0x00, 0xc0, 0xff, 0x07,
   0x00, 0x08, 0xb0, 0x00, 0x40, 0x00, 0x18, 0x80, 0x0f, 0x8c, 0x00, 0x7f,
   0x00, 0x20, 0x80, 0x08, 0x83, 0x00, 0x40, 0x00, 0x40, 0x80, 0xc8, 0x80,
   0x00, 0x40, 0x00, 0x40, 0x80, 0xf8, 0xff, 0x00, 0x40, 0x00, 0xc0, 0x83,
   0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x84, 0x00, 0x00, 0x00, 0x40, 0x00,
   0x40, 0xfc, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x04, 0x00, 0x00, 0x00,
   0x40, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00,
   0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40,
   0x00, 0x00, 0x00, 0x00, 0x7f, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40,
   0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x18, 0x00, 0x00, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00

   };

/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                    XschInitializeIcon                      |
|                                                             |
\------------------------------------------------------------*/

void XschInitializeIcon()

{
  autbegin();

  XschSetIcon( XschTopLevel, 
                IconBits, IconWidth, IconHeight );

  autend();
}

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/xsch/src/XMX_icon.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XSCH                            |
|                                                             |
| File    :                   Icon.c                          |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                   01.06.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include <stdio.h>
# include <Xm/Xm.h>
# include <Xm/PushB.h>
# include <Xm/Form.h>
# include <Xm/Frame.h>
 
# include "mut.h"
# include "aut.h"
# include "mlo.h"
# include "XSB.h"
# include "XTB.h"
# include "XMX.h"

# include "XMX_icon.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/

  static char IconBits[] = {

   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x07,
   0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x7f,
   0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00,
   0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0xc0, 0x03,
   0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x04, 0x00, 0x00, 0x00, 0x40, 0x00,
   0x40, 0xfc, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x84, 0x00, 0x00, 0x00,
   0x40, 0x00, 0xc0, 0x83, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x80, 0x00,
   0x00, 0x00, 0x40, 0x00, 0x40, 0x80, 0xf8, 0xff, 0x00, 0x40, 0x00, 0x40,
   0x80, 0xc8, 0x80, 0x00, 0x7f, 0x00, 0x40, 0x80, 0x08, 0x83, 0x00, 0x40,
   0x00, 0x20, 0x80, 0x0f, 0x8c, 0x00, 0x40, 0x00, 0x18, 0x00, 0x08, 0xb0,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x08, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x03,
   0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,
   0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xc0, 0x00, 0xc0, 0xff, 0x07,
   0x00, 0x08, 0xb0, 0x00, 0x40, 0x00, 0x18, 0x80, 0x0f, 0x8c, 0x00, 0x7f,
   0x00, 0x20, 0x80, 0x08, 0x83, 0x00, 0x40, 0x00, 0x40, 0x80, 0xc8, 0x80,
   0x00, 0x40, 0x00, 0x40, 0x80, 0xf8, 0xff, 0x00, 0x40, 0x00, 0xc0, 0x83,
   0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x84, 0x00, 0x00, 0x00, 0x40, 0x00,
   0x40, 0xfc, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x04, 0x00, 0x00, 0x00,
   0x40, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00,
   0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40,
   0x00, 0x00, 0x00, 0x00, 0x7f, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40,
   0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x18, 0x00, 0x00, 0x00,
   0x00, 0xc0, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00

   };

/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                    XschInitializeIcon                      |
|                                                             |
\------------------------------------------------------------*/

void XschInitializeIcon()

{
  autbegin();

  XschSetIcon( XschTopLevel, 
                IconBits, IconWidth, IconHeight );

  autend();
}
